@@ -1,11 +1,8 @@
-
-use std::ffi::{ c_void, CString };
 pub use crate::interfaces::*;
+use std::ffi::{c_void, CString};
 
-pub type CreateInterfaceFn = extern "system" fn(
-	pName: *const i8,
-	pReturnCode: *mut i32
-) -> *mut c_void;
+pub type CreateInterfaceFn =
+	extern "system" fn(pName: *const i8, pReturnCode: *mut i32) -> *mut c_void;
 
 ///  # Safety
 /// This function is unsafe to transmute the internal libloading symbol to a proper createinterface function pointer.
@@ -13,26 +10,28 @@ pub unsafe fn get_interface_handle(file: &str) -> Result<CreateInterfaceFn, libl
 	let lib = libloading::Library::new(file)?;
 	let sym: libloading::Symbol<CreateInterfaceFn> = lib.get(b"CreateInterface\0")?;
 
-	Ok( std::mem::transmute(sym) )
+	Ok(std::mem::transmute(sym))
 }
 
 #[derive(Debug)]
 pub enum InterfaceError {
-	BadCString( std::ffi::NulError ),
+	BadCString(std::ffi::NulError),
 	FactoryNotFound,
 }
 
-pub fn get_from_interface(iface: &str, factory: CreateInterfaceFn) -> Result<*mut (), InterfaceError> {
+pub fn get_from_interface(
+	iface: &str,
+	factory: CreateInterfaceFn,
+) -> Result<*mut (), InterfaceError> {
 	let mut status = 0;
 
-	let iface = CString::new(iface)
-		.map_err(InterfaceError::BadCString)?;
+	let iface = CString::new(iface).map_err(InterfaceError::BadCString)?;
 
-	let result = factory( iface.as_ptr(), &mut status );
+	let result = factory(iface.as_ptr(), &mut status);
 
 	if status == 0 && !result.is_null() {
 		Ok(result as *mut ())
 	} else {
-		Err( InterfaceError::FactoryNotFound )
+		Err(InterfaceError::FactoryNotFound)
 	}
-}
\ No newline at end of file
+}
