@@ -8,7 +8,7 @@ use std::os::raw::c_char;
 #[has_vtable]
 #[derive(VTable, Debug)]
 pub struct EngineClient {
-	pub vtable: usize
+	pub vtable: usize,
 }
 
 impl EngineClient {
@@ -38,4 +38,4 @@ impl EngineClient {
 
 	#[virtual_index(113)]
 	pub fn ClientCmd_Unrestricted(&self, command: *const c_char) {}
-}
\ No newline at end of file
+}
